import { createEditor } from '@modern-js-block/runtime';
import { getShapeStyle, mapToOptions, rendererMap, getDataLabelControls, getTooltipControls } from "./shared";
import PieChart from "../PieChart";
createEditor(PieChart, params => {
  const {
    ControlType,
    addPropertyControls
  } = params;
  addPropertyControls({
    data: {
      type: ControlType.Json,
      title: '图表数据',
      defaultValue: [{
        type: '分类一',
        value: 27
      }, {
        type: '分类二',
        value: 25
      }, {
        type: '分类三',
        value: 18
      }, {
        type: '分类四',
        value: 15
      }, {
        type: '分类五',
        value: 10
      }, {
        type: '其他',
        value: 5
      }]
    },
    angleField: {
      type: ControlType.String,
      title: '切片大小字段名'
    },
    colorField: {
      type: ControlType.String,
      title: '扇形颜色映射字段名'
    },
    radius: {
      type: ControlType.Number,
      title: '圆形半径',
      min: 0,
      max: 1,
      step: 0.01
    },
    innerRadius: {
      type: ControlType.Number,
      title: '内圆半径',
      min: 0,
      max: 1,
      step: 0.01
    },
    startAngle: {
      type: ControlType.Number,
      title: '起始角度'
    },
    endAngle: {
      type: ControlType.Number,
      title: '结束角度'
    },
    label: {
      type: ControlType.Object,
      title: '数据标签',
      propertyControls: getDataLabelControls(params)
    },
    tooltip: {
      type: ControlType.Object,
      title: 'Tooltip',
      propertyControls: getTooltipControls(params)
    },
    statistic: {
      type: ControlType.Json,
      title: '统计内容'
    },
    width: {
      type: ControlType.Number,
      title: '宽度'
    },
    height: {
      type: ControlType.Number,
      title: '高度'
    },
    autoFit: {
      type: ControlType.Boolean,
      title: '自适应'
    },
    renderer: {
      type: ControlType.Enum,
      title: '渲染方式',
      options: mapToOptions(rendererMap)
    },
    limitInPlot: {
      type: ControlType.Boolean,
      title: '超出内容裁剪'
    },
    meta: {
      type: ControlType.Json,
      title: 'Meta 信息'
    },
    legend: {
      type: ControlType.Json,
      title: '图例信息(legend)'
    },
    pieStyle: {
      type: ControlType.Object,
      title: '扇形图形样式',
      propertyControls: getShapeStyle(params)
    }
  });
});