import { createBlock } from '@modern-js-block/runtime';
import { Heatmap, HeatmapOptions } from '@antv/g2plot';
import { createChart, Data } from '@/base';

export interface HeatmapChartProps
  extends Omit<HeatmapOptions, 'data' | 'angleField'> {
  data?: Data;
}

const HeatmapChart = createChart<HeatmapChartProps>(Heatmap, {
  transformData: (options: any) => {
    const { xField, data = [], isSorted } = options;
    if (isSorted) {
      return data.sort((a: any, b: any) => a[xField] - b[xField]);
    }
    return data;
  },
});

export default createBlock<HeatmapChartProps>({
  width: 650,
  height: 500,
  autoFit: false,
  data: [],
  xField: 'Month of Year',
  yField: 'District',
  colorField: 'AQHI',
  color: ['#174c83', '#7eb6d4', '#efefeb', '#efa759', '#9b4d16'],
})(HeatmapChart);
