import { createEditor, PluginParams } from '@modern-js-block/runtime';
import {
  getShapeStyle,
  mapToOptions,
  rendererMap,
  getAxisControls,
  getLegendControls,
  getDataLabelControls,
  getTooltipControls,
} from './shared';
import BarChart from '@/BarChart';

createEditor(BarChart, (params: PluginParams) => {
  const { ControlType, addPropertyControls } = params;
  addPropertyControls({
    data: {
      type: ControlType.Json,
      title: '图表数据',
      defaultValue: [
        { x: '1951 年', y: 38 },
        { x: '1952 年', y: 52 },
        { x: '1956 年', y: 61 },
        { x: '1957 年', y: 145 },
        { x: '1958 年', y: 48 },
      ],
    },
    xField: {
      type: ControlType.String,
      title: 'x 轴字段名',
    },
    yField: {
      type: ControlType.String,
      title: 'y 轴字段名',
    },
    seriesField: {
      type: ControlType.String,
      title: '分组字段名',
      tips: '用于同时看一个维度中不同情况的指标需求',
    },
    groupField: {
      type: ControlType.String,
      title: '堆叠分组字段名',
      tips: '拆分优先级高于 seriesField，isGroup: true 时会根据 groupField 进行分组',
    },
    isGroup: {
      type: ControlType.Boolean,
      title: '分组条形图',
    },
    isStack: {
      type: ControlType.Boolean,
      title: '堆积条形图',
    },
    isRange: {
      type: ControlType.Boolean,
      title: '区间条形图',
    },
    isPercent: {
      type: ControlType.Boolean,
      title: '堆积百分比条形图',
    },
    barWidthRatio: {
      type: ControlType.Number,
      title: '条形图宽度占比[0-1]',
    },
    minBarWidth: {
      type: ControlType.Number,
      title: '条形图最小宽度设置',
    },
    maxBarWidth: {
      type: ControlType.Number,
      title: '条形图最大宽度设置',
    },
    xAxis: {
      type: ControlType.Object,
      title: 'x 坐标轴',
      propertyControls: getAxisControls(params),
    },
    yAxis: {
      type: ControlType.Object,
      title: 'y 坐标轴',
      propertyControls: getAxisControls(params),
    },
    legend: {
      type: ControlType.Object,
      title: '图例 Legend',
      propertyControls: getLegendControls(params),
    },
    label: {
      type: ControlType.Object,
      title: '数据标签',
      propertyControls: getDataLabelControls(params),
    },
    tooltip: {
      type: ControlType.Object,
      title: 'Tooltip',
      propertyControls: getTooltipControls(params),
    },
    width: {
      type: ControlType.Number,
      title: '宽度',
    },
    height: {
      type: ControlType.Number,
      title: '高度',
    },
    autoFit: {
      type: ControlType.Boolean,
      title: '自适应',
    },
    renderer: {
      type: ControlType.Enum,
      title: '渲染方式',
      options: mapToOptions(rendererMap),
    },
    limitInPlot: {
      type: ControlType.Boolean,
      title: '超出内容裁剪',
    },
    meta: {
      type: ControlType.Json,
      title: 'Meta 信息',
    },
    barStyle: {
      type: ControlType.Object,
      title: '柱子样式',
      propertyControls: getShapeStyle(params),
    },
  });
});
