/* eslint-disable max-lines */
import { PluginParams } from '@modern-js-block/runtime';

export const mapToOptions = (
  map: Record<string, string | number | boolean> = {},
) => Object.entries(map).map(([value, label]) => ({ label, value }));

export const rendererMap = {
  canvas: 'Canvas',
  svg: 'SVG',
};

export const xAxisTypeMap = {
  cat: '分类度量 - cat',
  timeCat: '时间分类度量 - timeCat',
  linear: '线性度量 - linear',
  time: '连续时间度量 - time',
  log: 'log 度量',
  pow: 'pow 度量',
  quantize: '分段度量 - quantize',
  quantile: '等分度量 - quantile',
  identity: '常量度量 - identity',
};

export const positionMap = {
  top: '顶部',
  bottom: '底部',
  left: '左侧',
  right: '右侧',
};

export const getShapeStyle = ({ ControlType }: PluginParams): any => ({
  fill: {
    type: ControlType.Color,
    title: '图形填充色',
    tips: 'fill',
  },
  fillOpacity: {
    type: ControlType.Number,
    title: '图形透明度',
    tips: 'fillOpacity',
  },
  stroke: {
    type: ControlType.Color,
    title: '图形描边',
    tips: 'stroke',
  },
  lineWidth: {
    type: ControlType.Number,
    title: '描边宽度',
    tips: 'lineWidth',
  },
  lineOpacity: {
    type: ControlType.Number,
    title: '描边透明度',
    tips: 'lineOpacity',
  },
  opacity: {
    type: ControlType.Number,
    title: '整体透明度',
    tips: 'opacity',
  },
  shadowColor: {
    type: ControlType.Color,
    title: '图形阴影颜色',
    tips: 'shadowColor',
  },
  strokeOpacity: {
    type: ControlType.Number,
    title: '图形边框透明度',
    tips: 'strokeOpacity',
  },
  shadowOffsetX: {
    type: ControlType.Number,
    title: '阴影距图形的水平距离',
    tips: 'shadowOffsetX',
  },
  shadowOffsetY: {
    type: ControlType.Number,
    title: '阴影距图形的垂直距离',
    tips: 'shadowOffsetY',
  },
});

export const getAxisControls = ({ ControlType }: PluginParams): any => ({
  type: {
    type: ControlType.Enum,
    title: '度量类型',
    options: mapToOptions(xAxisTypeMap),
  },
  min: {
    type: ControlType.Number,
    title: '坐标轴最小值',
  },
  max: {
    type: ControlType.Number,
    title: '坐标轴最大值',
  },
  minLimit: {
    type: ControlType.Number,
    title: '最小值限定',
  },
  maxLimit: {
    type: ControlType.Number,
    title: '最大值限定',
  },
  tickCount: {
    type: ControlType.Number,
    title: '坐标轴刻度数量',
  },
  tickInterval: {
    type: ControlType.Number,
    title: '坐标轴刻度间隔',
  },
  position: {
    type: ControlType.Enum,
    title: '坐标轴位置',
    options: mapToOptions(positionMap),
  },
  nice: {
    type: ControlType.Boolean,
    title: '是否美化',
  },
  animate: {
    type: ControlType.Boolean,
    title: '开启动画',
  },
  verticalFactor: {
    type: ControlType.Enum,
    title: '坐标轴 label 方向',
    options: [
      { label: '左侧', value: 1 },
      { label: '右侧', value: -1 },
    ],
  },
  verticalLimitLength: {
    type: ControlType.Number,
    title: '垂直方向的最大限制长度',
  },
  mask: {
    type: ControlType.String,
    title: 'mask',
    tips: '时间度量 time, timeCat 时有效',
  },
  title: {
    type: ControlType.Object,
    title: '标题配置',
    propertyControls: {
      text: {
        type: ControlType.String,
        title: '坐标轴标题',
      },
      offset: {
        type: ControlType.Number,
        title: '偏移量',
      },
      autoRotate: {
        type: ControlType.Boolean,
        title: '文本自动旋转',
      },
    },
  },
  label: {
    type: ControlType.Object,
    title: '标签配置',
    propertyControls: {
      offset: {
        type: ControlType.Number,
        title: '偏移量',
      },
      rotate: {
        type: ControlType.Number,
        title: '文本旋转角度',
      },
      autoRotate: {
        type: ControlType.Boolean,
        title: '文本自动旋转',
      },
      autoHide: {
        type: ControlType.Boolean,
        title: '自动隐藏',
      },
      autoEllipsis: {
        type: ControlType.Boolean,
        title: '自动省略',
      },
      formatterStr: {
        type: ControlType.String,
        title: '格式化展示',
        tips: '如 {value*100}%',
      },
    },
  },
  grid: {
    type: ControlType.Json,
    title: '网格线配置',
  },
});

export const getDataLabelControls = ({ ControlType }: PluginParams): any => ({
  type: {
    type: ControlType.String,
    title: '类型',
  },
  offset: {
    type: ControlType.Number,
    title: '偏移量',
  },
  offsetX: {
    type: ControlType.Number,
    title: 'X 方向偏移量',
  },
  offsetY: {
    type: ControlType.Number,
    title: 'Y 方向偏移量',
  },
  content: {
    type: ControlType.String,
    title: '展示的文本内容',
  },
  autoRotate: {
    type: ControlType.Boolean,
    title: '自动旋转',
  },
  rotate: {
    type: ControlType.Number,
    title: '文本旋转角度',
  },
  position: {
    type: ControlType.Enum,
    title: '位置',
    options: mapToOptions(positionMap),
  },
  animate: {
    type: ControlType.Boolean,
    title: '开启动画',
  },
  autoHide: {
    type: ControlType.Boolean,
    title: '自动隐藏',
  },
  style: {
    type: ControlType.Json,
    title: '样式',
  },
});

export const getTooltipControls = (params: PluginParams): any => {
  const { ControlType } = params;
  return {
    follow: {
      type: ControlType.Boolean,
      title: '内容随鼠标移动',
    },
    enterable: {
      type: ControlType.Boolean,
      title: '允许鼠标滑入',
    },
    showTitle: {
      type: ControlType.Boolean,
      title: '展示标题',
    },
    title: {
      type: ControlType.Text,
      title: '标题',
      autoSize: true,
    },
    offset: {
      type: ControlType.Number,
      title: '偏移量',
    },
    formatterStr: {
      type: ControlType.String,
      title: '格式化展示',
      tips: '如 {value}%',
    },
    shared: {
      type: ControlType.Boolean,
      title: '合并数据展示',
    },
    position: {
      type: ControlType.Enum,
      title: '位置',
      options: mapToOptions(positionMap),
    },
    animate: {
      type: ControlType.Boolean,
      title: '开启动画',
    },
    autoHide: {
      type: ControlType.Boolean,
      title: '自动隐藏',
    },
    showMarkers: {
      type: ControlType.Boolean,
      title: '渲染 tooltipMarkers',
    },
    showContent: {
      type: ControlType.Boolean,
      title: '渲染 tooltip 内容框',
    },
    showCrosshairs: {
      type: ControlType.Boolean,
      title: '展示 crosshairs',
    },
    crosshairs: {
      type: ControlType.Json,
      title: 'crosshairs',
    },
    shapeStyle: {
      type: ControlType.Object,
      title: '图形样式',
      tips: 'shapeStyle',
      propertyControls: getShapeStyle(params),
    },
    textBackgroundStyle: {
      type: ControlType.Json,
      title: '文本背景样式',
    },
    style: {
      type: ControlType.Json,
      title: '样式',
    },
  };
};

export const getLegendControls = (params: PluginParams): any => {
  const { ControlType } = params;
  return {
    layout: {
      type: ControlType.Enum,
      title: '布局方式',
      options: mapToOptions({
        horizontal: '水平',
        vertical: '垂直',
      }),
    },
    position: {
      type: ControlType.Enum,
      title: '位置',
      options: mapToOptions({
        top: '顶部',
        'top-left': '顶部左侧',
        'top-right': '顶部右侧',
        right: '右侧',
        'right-top': '右侧顶部',
        'right-bottom': '右侧底部',
        left: '左侧',
        'left-top': '左侧顶部',
        'left-bottom': '左侧底部',
        bottom: '底部',
        'bottom-left': '底部左侧',
        'bottom-right': '底部右侧',
      }),
    },
    flipPage: {
      type: ControlType.Boolean,
      title: '图例分页',
    },
    animate: {
      type: ControlType.Boolean,
      title: '开启动画',
    },
    reversed: {
      type: ControlType.Boolean,
      title: '逆序展示',
    },
    slidable: {
      type: ControlType.Boolean,
      title: '可滑动',
    },
    min: {
      type: ControlType.Number,
      title: '范围最小值',
    },
    max: {
      type: ControlType.Number,
      title: '范围最大值',
    },
    itemSpacing: {
      type: ControlType.Number,
      title: '图例水平方向间距',
    },
    marker: {
      type: ControlType.Json,
      title: '图例形状',
    },
  };
};
/* eslint-enable max-lines */
